<?php
// include common definitions
require_once 'diogenes.common.inc.php';
require_once 'diogenes.toplevel.inc.php';
require_once 'diogenes.barrel.options.inc.php';

$page = new $globals->toplevel;

$page->assign('greeting', __("Welcome to Diogenes")."!");
$page->assign('about',
  $globals->urlise(__("Welcome to the Diogenes content management system.")." ".
  __("Diogenes was developed by the webmasters of the Polytechnique.org web site.")));
$page->assign('available',__("The following barrels are currently available"));
$page->assign('msg_site',__("site"));
$page->assign('msg_desc',__("description"));

$res = $globals->db->query("select alias,vhost from diogenes_site order by alias");
$odd = false;
while (list($s_alias,$s_vhost) = mysql_fetch_row($res)) {
  $opts = new DiogenesBarrelOptions($s_alias);
  $page->append('barrels',
    array($odd ? "odd" : "even", 
          array($opts->title, $page->urlBarrel($s_alias,$s_vhost)),
          $opts->description,
          array("[admin]",$page->urlBarrel($s_alias,$s_vhost,"admin/"))
    ));
  $odd = !$odd;
}
mysql_free_result($res);

$page->display("index.tpl");
?>
